OPTIONS NOCENTER NoSource NoNotes NoSpool NoDate NoNumber;
/* Generating multiple datasets of size 137 - power for OR=2 effect size */


/* writing log and output info to external files */
proc printto log='c:\DATA\POWER\LReg_power_N=137.log';
proc printto print='c:\DATA\POWER\LReg_power_N=137.lst';
run;

DATA parms;
* number of datasets ;
ndats = 10000;
* number of subjects per group;
npergrp = 137;
* total number of subjects ;
nsubj = 2*npergrp;
* effect size for the group difference;
oddsratio = 2;
* seed for random number generation;
seed   = 974657747;

******************************************************************************************;
* NOTHING BELOW NEEDS TO BE SPECIFIED;
******************************************************************************************;


data simdat; set parms;
ndat=1;
do while (ndat le ndats);
   n=1;
   do while (n le nsubj);
      grp = 0; if n > npergrp then grp = 1;
      exp1 =  ranexp(seed);
      exp2 =  ranexp(seed);
      err = LOG(exp1/exp2);
      ystar = LOG(oddsratio)*grp + err;
      y    = 0;if ystar > 0 then y = 1;
      output simdat;
   n+1;
   end;
ndat+1;
end;


/* logistic regression model */
proc logistic descending;
model y = grp ;
by ndat;
ods output 'Parameter Estimates'=parmest;
run;



data grpest; set parmest; by ndat;
/* select only the grp effect */
if variable = 'grp';
EstOddsRatio = EXP(ESTIMATE);

/* summarize the results of the regression model */
data sumres;
IF _N_ = 1 THEN set parms; set grpest;

reject = 0;
if (ABS(ESTIMATE/STDERR) > 1.95996) then reject = 1;

proc means noprint; var ndats npergrp EstOddsRatio oddsratio reject;
output out = outres  mean(ndats npergrp EstOddsRatio oddsratio reject) = ndatasets numpergrp estm truev rejrate;
run;


/* write out the results */
DATA outfile; set outres (keep = ndatasets numpergrp truev estm rejrate);
FILE 'c:\data\power\LReg_power_N=137.txt';
put (ndatasets numpergrp) (6.0) (truev estm rejrate) (12.6);
run;

PROC EXPORT DATA= outfile
            OUTFILE= 'c:\data\power\LReg_power_N=137.xls'
            DBMS=EXCEL2000 REPLACE;
RUN;
