OPTIONS NOCENTER NoSource NoNotes NoSpool NoDate NoNumber;
/* Generating multiple datasets of size 33 - Random Intercept model power for .5 effect size */


/* writing log and output info to external files */
proc printto log='U:\Restore_Sph1\C\DATA\Power\RandInt_power_N=33.log';
proc printto print='U:\Restore_Sph1\C\DATA\Power\RandInt_power_N=33.lst';
run;

DATA parms;
* number of datasets ;
ndats = 5000;
* number of timepoints;
ntime = 5;
* number of subjects per group;
npergrp = 33;
* total number of subjects ;
nsubj = 2*npergrp;
* effect size for the group difference;
effsize = .5;
* ICC for repeated outcomes;
icc = .4;
* seed for random number generation;
seed   = 974657747;

******************************************************************************************;
* NOTHING BELOW NEEDS TO BE SPECIFIED;
******************************************************************************************;

* calculate the subject & error variances, assuming the subject plus error variance equals 1;
varsub = icc;
varerr = (1-icc);
data simdat; set parms;
ndat=1;
do while (ndat le ndats);
   n=1;
   do while (n le nsubj);
      grp = 0; if n > npergrp then grp = 1;
          subj = SQRT(varsub)*RANNOR(SEED);
          j=1;
          do while (j le ntime);
            err = SQRT(varerr)*RANNOR(SEED);
            y = effsize*grp + subj + err;
            output simdat;
          j+1;end;
   n+1;end;
ndat+1;end;


/* random intercept model */
proc mixed noclprint;
class n;
model y = grp /s;
random intercept/subject=n;
by ndat;
ods output SolutionF=parmest;
run;


data grpest; set parmest; by ndat;
/* select only the grp effect */
if effect = 'grp';


/* summarize the results of the regression model */
data sumres;
IF _N_ = 1 THEN set parms; set grpest;

reject = 0;
if (ABS(ESTIMATE/STDERR) > 1.95996) then reject = 1;



proc means noprint; var ndats npergrp ntime icc estimate effsize reject;
output out = outres  mean(ndats npergrp ntime icc estimate effsize reject) = ndatasets numpergrp numtime intclass estm truev rejrate;
run;


/* write out the results */
DATA outfile; set outres (keep = ndatasets numpergrp numtime intclass truev estm rejrate);
FILE 'U:\Restore_Sph1\C\DATA\Power\RandInt_power_N=33.txt';
put (ndatasets numpergrp numtime) (6.0) (intclass) (7.3) (truev estm rejrate) (12.6);
run;

PROC EXPORT DATA= outfile
            OUTFILE= 'U:\Restore_Sph1\C\DATA\Power\RandInt_power_N=33.xls'
            DBMS=EXCEL2000 REPLACE;
RUN;
