OPTIONS NOCENTER NoSource NoNotes NoSpool NoDate NoNumber;
/* Generating multiple datasets of size 63 - t-test power for .5 effect size */


/* writing log and output info to external files */
proc printto log='c:\DATA\POWER\Ttest_power_N=63.log';
proc printto print='c:\DATA\POWER\Ttest_power_N=63.lst';
run;

DATA parms;
* number of datasets ;
ndats = 5000;
* number of subjects per group;
npergrp = 63;
* total number of subjects ;
nsubj = 2*npergrp;
* effect size for the group difference;
effsize = .5;
* seed for random number generation;
seed   = 974657747;

******************************************************************************************;
* NOTHING BELOW NEEDS TO BE SPECIFIED;
******************************************************************************************;


data simdat; set parms;
ndat=1;
do while (ndat le ndats);
   n=1;
   do while (n le nsubj);
      grp = 0; if n > npergrp then grp = 1;
      err = RANNOR(SEED);
      y = effsize*grp + err;
      output simdat;
   n+1;
   end;
ndat+1;
end;


/* regression model */
proc reg;
model y = grp ;
by ndat;
ods output 'Parameter Estimates'=parmest;
run;



data grpest; set parmest; by ndat;
/* select only the grp effect */
if variable = 'grp';


/* summarize the results of the regression model */
data sumres;
IF _N_ = 1 THEN set parms; set grpest;

reject = 0;
if (ABS(ESTIMATE/STDERR) > 1.95996) then reject = 1;

proc means noprint; var ndats npergrp estimate effsize reject;
output out = outres  mean(ndats npergrp estimate effsize reject) = ndatasets numpergrp estm truev rejrate;
run;


/* write out the results */
DATA outfile; set outres (keep = ndatasets numpergrp truev estm rejrate);
FILE 'c:\data\power\Ttest_power_N=63.txt';
put (ndatasets numpergrp) (6.0) (truev estm rejrate) (12.6);
run;

PROC EXPORT DATA= outfile
            OUTFILE= 'c:\data\power\Ttest_power_N=63.xls'
            DBMS=EXCEL2000 REPLACE;
RUN;
